==> FixRaidenBoss2-4.0.1-py3-none-any.whl: FixRaidenBoss2/data/IndexData.py <==
##### Credits

# ===== Anime Game Remap (AG Remap) =====
# Authors: NK#1321, Albert Gold#2696
#
# if you used it to remap your mods pls give credit for "Nhok0169" and "Albert Gold#2696"
# Special Thanks:
#   nguen#2011 (for support)
#   SilentNightSound#7430 (for internal knowdege so wrote the blendCorrection code)
#   HazrateGolabi#1364 (for being awesome, and improving the code)

##### EndCredits


##### Script
IndexData = {4.0 : {"Amber": {"head": "0", "body": "5670"},
        "AmberCN": {"head": "0", "body": "5670"},
        "Barbara": {"head": "0", "body": "12015", "dress": "46248"},
        "BarbaraSummertime": {"head": "0", "body": "11943", "dress": "45333"},
        "Fischl": {"head": "0", "body": "11535", "dress": "42471"},
        "FischlHighness": {"head": "0", "body": "23091"},
        "Ganyu": {"head": "0", "body": "12822", "dress": "47160"},
        "Jean": {"head": "0", "body": "7779"},
        "JeanCN": {"head": "0", "body": "7779"},
        "JeanSea": {"head": "0", "body": "7662", "dress": "52542"},
        "Keqing": {"head": "0", "body": "10824", "dress": "48216"},
        "KeqingOpulent": {"head": "0", "body": "19623"},
        "Mona": {"head": "0", "body": "17688"},
        "MonaCN": {"head": "0", "body": "17688"},
        "Nilou": {"head": "0", "body": "44844", "dress": "64080"},
        "Ningguang": {"head": "0", "body": "12384", "dress": "47157"},
        "NingguangOrchid": {"head": "0", "body": "43539", "dress": "56124"},
        "Rosaria": {"head": "0", "body": "11139", "dress": "44088", "extra": "45990"},
        "RosariaCN": {"head": "0", "body": "11025", "dress": "46539", "extra": "48441"},
        "Shenhe": {"head": "0", "body": "14385", "dress": "48753"}},
        4.4: {"ShenheFrostFlower": {"head": "0", "body": "31326", "dress": "66588", "extra": "70068"},
              "GanyuTwilight": {"head": "0", "body": "50817", "dress": "74235"}},
        4.6: {"Arlecchino": {"head": "0", "body": "40179", "dress": "74412"},
              "ArlecchinoBoss": {"head": "0", "body": "40179", "dress": "74412"}},
        4.8: {"NilouBreeze": {"head": "0", "body": "44538", "dress": "73644"}}}
##### EndScript

==> FixRaidenBoss2-4.2.2-py3-none-any.whl: FixRaidenBoss2/data/IndexData.py <==
##### Credits

# ===== Anime Game Remap (AG Remap) =====
# Authors: Albert Gold#2696, NK#1321
#
# if you used it to remap your mods pls give credit for "Albert Gold#2696" and "Nhok0169"
# Special Thanks:
#   nguen#2011 (for support)
#   SilentNightSound#7430 (for internal knowdege so wrote the blendCorrection code)
#   HazrateGolabi#1364 (for being awesome, and improving the code)

##### EndCredits


##### Script
IndexData = {4.0 : {"Amber": {"head": "0", "body": "5670"},
        "AmberCN": {"head": "0", "body": "5670"},
        "Ayaka": {"head": "0", "body": "11565", "dress": "58209"},
        "AyakaSpringBloom": {"head": "0", "body": "56223", "dress": "69603"},
        "Barbara": {"head": "0", "body": "12015", "dress": "46248"},
        "BarbaraSummertime": {"head": "0", "body": "11943", "dress": "45333"},
        "Diluc": {"head": "0", "body": "10896"},
        "DilucFlamme": {"head": "0", "body": "38061", "dress": "56010"},
        "Fischl": {"head": "0", "body": "11535", "dress": "42471"},
        "FischlHighness": {"head": "0", "body": "23091"},
        "Ganyu": {"head": "0", "body": "12822", "dress": "47160"},
        "Jean": {"head": "0", "body": "7779"},
        "JeanCN": {"head": "0", "body": "7779"},
        "JeanSea": {"head": "0", "body": "7662", "dress": "52542"},
        "Keqing": {"head": "0", "body": "10824", "dress": "48216"},
        "KeqingOpulent": {"head": "0", "body": "19623"},
        "Kirara": {"head": "0", "body": "37128", "dress": "75234"},
        "Klee": {"head": "0", "body": "8436"},
        "KleeBlossomingStarlight": {"head": "0", "body": "32553", "dress": "82101"},
        "Mona": {"head": "0", "body": "17688"},
        "MonaCN": {"head": "0", "body": "17688"},
        "Nilou": {"head": "0", "body": "44844", "dress": "64080"},
        "Ningguang": {"head": "0", "body": "12384", "dress": "47157"},
        "NingguangOrchid": {"head": "0", "body": "43539", "dress": "56124"},
        "Rosaria": {"head": "0", "body": "11139", "dress": "44088", "extra": "45990"},
        "RosariaCN": {"head": "0", "body": "11025", "dress": "46539", "extra": "48441"},
        "Shenhe": {"head": "0", "body": "14385", "dress": "48753"},
        "Xingqiu": {"head": "0", "body": "6132"}},
        4.4: {"ShenheFrostFlower": {"head": "0", "body": "31326", "dress": "66588", "extra": "70068"},
              "GanyuTwilight": {"head": "0", "body": "50817", "dress": "74235"},
              "XingqiuBamboo": {"head": "0", "body": "32508", "dress": "62103"}},
        4.6: {"Arlecchino": {"head": "0", "body": "40179", "dress": "74412"},
              "ArlecchinoBoss": {"head": "0", "body": "40179", "dress": "74412"}},
        4.8: {"NilouBreeze": {"head": "0", "body": "44538", "dress": "73644"},
              "KiraraBoots": {"head": "0", "body": "36804", "dress": "80295"}}}
##### EndScript
